@@ -95,7 +95,7 @@ def __parse_arguments(only_known: bool) -> argparse.Namespace:
         dest="selector",
         action="store",
         type=str,
-        choices=["rofi", "wofi", "fuzzel"],
+        choices=["rofi", "wofi", "fuzzel", "dmenu"],
         default=None,
         help="Choose the application to select the characters with",
     )
