@@ -1,18 +1,22 @@
 from dataclasses import dataclass
-import enum
+from enum import Enum
 
 
-class Action(enum.Enum):
-    TYPE = 'type'
-    COPY = 'copy'
-    CLIPBOARD = 'clipboard'
-    UNICODE = 'unicode'
-    COPY_UNICODE = 'copy-unicode'
-    STDOUT = 'print'
+class Action(Enum):
+    TYPE = "type"
+    COPY = "copy"
+    CLIPBOARD = "clipboard"
+    UNICODE = "unicode"
+    COPY_UNICODE = "copy-unicode"
+    STDOUT = "print"
+    MENU = "menu"
 
     def __str__(self):
         return self.value
 
+    def __repr__(self):
+        return self.value
+
 
 class CANCEL:
     def __eq__(self, other):
